@@ -1,21 +1,13 @@
-from cgi import parse_header
 from mimetypes import guess_extension
 from os import environ
 
 import click
 
-from kks.ejudge import Status, ejudge_summary, ejudge_statement, ejudge_submissions, ejudge_report
+from kks.ejudge import Status, ejudge_summary, ejudge_submissions, ejudge_report
 from kks.util.click import OptFlagCommand, FlagOption, OptFlagOption, Choice2
 from kks.util.common import find_workspace, get_task_dir, write_contests
 from kks.util.ejudge import EjudgeSession
-from kks.errors import AuthError
-
-
-def source_suf(problem):
-    pref = problem.name.split('/', 1)[0]
-    if pref == 'asm':
-        return '.S'
-    return '.c'
+from kks.util.storage import Config
 
 
 def save_needed(problem, submissions, sub_dir, session, full_sync):
@@ -25,11 +17,13 @@ def save_needed(problem, submissions, sub_dir, session, full_sync):
     def format_stem(submission):
         return f'{prefix(submission)}-{submission.short_status()}'
 
-    def get_extension(problem, resp):
+    def get_extension(submission, resp):
+        from cgi import parse_header
+
         mimetype, _ = parse_header(resp.headers.get('Content-Type', ''))
         mimetype = mimetype.lower()
         if mimetype == 'text/plain':
-            return source_suf(problem)
+            return submission.suffix()
         elif mimetype == 'application/x-gzip':
             return '.gz'
         else:
@@ -75,7 +69,7 @@ def save_needed(problem, submissions, sub_dir, session, full_sync):
 
         resp = session.get(sub.source)
 
-        file = file.with_suffix(get_extension(problem, resp))
+        file = file.with_suffix(get_extension(sub, resp))
 
         source = resp.content
         if sub.status in [Status.PARTIAL, Status.REJECTED]:
@@ -121,21 +115,17 @@ def sync(code, code_opt, force, filters):
         click.secho('You have to run sync under kks workspace (use "kks init" to create one)', fg='red', err=True)
         return
 
-    try:
-        session = EjudgeSession()
-    except AuthError:
-        return
+    config = Config()
 
+    session = EjudgeSession()
     problems = ejudge_summary(session)
-    if problems is None:
-        return
 
     code_all = code_opt == 'all'
     code = code or code_all
     if code:
         submissions = ejudge_submissions(session)
 
-    md_width = int(environ.get('MDWIDTH', '100'))
+    md_width = config.options.mdwidth
 
     contests = set()
     bad_contests = set()
@@ -181,7 +171,9 @@ def sync(code, code_opt, force, filters):
 
         new_problems += 1
 
-        main = (task_dir / problem.short_name).with_suffix(source_suf(problem))
+        problem = problem.get_full(session)
+
+        main = (task_dir / problem.short_name).with_suffix(problem.suffix())
         main.touch()
 
         gen = task_dir / 'gen.py'
@@ -200,20 +192,30 @@ def sync(code, code_opt, force, filters):
         tests_dir = task_dir / 'tests'
         tests_dir.mkdir(exist_ok=True)
 
-        statement = ejudge_statement(problem.href, session)
+        html_statement_path = task_dir / 'statement.html'
+        md_statement_path = task_dir / 'statement.md'
 
-        with (task_dir / 'statement.html').open('w') as f:
-            f.write(statement.html())
-        with (task_dir / 'statement.md').open('w') as f:
-            f.write(statement.markdown(width=md_width))
+        if config.options.save_html_statements:
+            if problem.statement_available() or not html_statement_path.exists():  # overwrite only if statement is available
+                with html_statement_path.open('w') as f:
+                    f.write(problem.html())
+        elif html_statement_path.is_file():
+            html_statement_path.unlink()
 
-        if statement.input_data is not None:
+        if config.options.save_md_statements:
+            if problem.statement_available() or not md_statement_path.exists():
+                with md_statement_path.open('w') as f:
+                    f.write(problem.markdown(width=md_width))
+        elif md_statement_path.is_file():
+            md_statement_path.unlink()
+
+        if problem.input_data is not None:
             with (tests_dir / '000.in').open('w') as f:
-                f.write(statement.input_data)
+                f.write(problem.input_data)
 
-        if statement.output_data is not None:
+        if problem.output_data is not None:
             with (tests_dir / '000.out').open('w') as f:
-                f.write(statement.output_data + '\n')
+                f.write(problem.output_data + '\n')
 
         if code:
             click.secho('Syncing submissions')
